
# Best Practices

## Resample
### When Transforming
data components끼리 연산할 때는 frequency를 맞춰주는게 좋다 등의 설명
### Lookback Selection
각 data component마다, 혹은 default frequency마다 lookback은 얼마정도로 주면 좋은지

## Universe Filte
### Examples
Example 1: 지역별로 universe 생성하고 싶을 때
Example 2: ETF로만 universe 생성하고 싶을 때

## Financial Components
Use of Preliminary

## Group Functions and Security Master Attribute
현재 Using Security Master Attribute as Data 안에 있는 gics_sector group 예시
의도한 use case를 설명
